import { h } from "@stencil/core";
import { Parser } from '../../infrastructure/parser';
export class XmlViewerComponent {
    componentDidLoad() {
    }
    // for FireFox and maybe Edge.
    toArray(obj) {
        let arr = [];
        for (let i = 0; i < obj.length; i++) {
            arr.push(obj[i]);
        }
        return arr;
    }
    prepareXml() {
        let xdoc = Parser.Parse(this.xml.trim());
        return xdoc;
    }
    renderAttribute(attribute) {
        return (h("span", null,
            "\u00A0",
            h("span", { class: "attr" },
                attribute.name,
                "=\"",
                h("span", { class: "attr-value" }, attribute.value),
                "\"")));
    }
    renderNodeValue(nodeValue) {
        if (!nodeValue) {
            return null;
        }
        if (nodeValue.length > 150) {
            return (h("ul", null,
                h("li", null, nodeValue)));
        }
        return (h("span", null, nodeValue));
    }
    // rendering node. This function calls to itself in recursion way in case of child nodes
    renderNode(node) {
        if (!node) {
            return null;
        }
        // Note: FireFox thinks node.children is an array but it's not. FF transpiles next two lines of code (not comments)
        // into node.children.slice() but as I said before, node.children is not an array.
        // It's ... So I have to convert it into an array manually (yeah I know it's a stupid workaround)
        // TODO: I have to figure oute how to solve this problem properly
        let children = this.toArray(node.children); //[...node.children];
        let attributes = this.toArray(node.attributes); //[...node.attributes];
        let nodeValue = node.firstChild ? node.firstChild.nodeValue : null;
        nodeValue = nodeValue ? nodeValue.trim() : null;
        return (h("ul", null,
            h("li", null,
                h("div", { class: "element" },
                    "<",
                    node.nodeName,
                    attributes.map(a => this.renderAttribute(a)),
                    ">"),
                h("div", { class: "element-content" }, this.renderNodeValue(nodeValue)),
                children.map(c => this.renderNode(c)),
                h("div", { class: "element" },
                    "</",
                    node.nodeName,
                    ">"))));
    }
    render() {
        if (this.xml === null || this.xml === undefined) {
            return null;
        }
        if (this.xml.length === 0) {
            return null;
        }
        let xdoc = null;
        try {
            xdoc = this.prepareXml();
        }
        catch (e) {
            console.error(e);
        }
        if (!xdoc || !xdoc.documentElement.childNodes) {
            return (h("code", null, this.xml));
        }
        return (h("p", null,
            h("code", null, this.renderNode(xdoc.documentElement))));
    }
    static get is() { return "xml-viewer-component"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["xml-viewer-component.css"]
    }; }
    static get styleUrls() { return {
        "$": ["xml-viewer-component.css"]
    }; }
    static get properties() { return {
        "xml": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "xml",
            "reflect": false
        }
    }; }
}
