import { r as registerInstance, h } from './core-277b56e5.js';

class Parser {
    static Parse(xmlstr) {
        if (typeof DOMParser !== 'undefined') {
            let domDoc = (new DOMParser()).parseFromString(xmlstr, 'application/xml');
            // let's check for errors
            if (domDoc.documentElement.nodeName == "parsererror") {
                throw new Error('XML parsing error');
            }
            return domDoc;
        }
        return null;
    }
}

const XmlViewerComponent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    componentDidLoad() {
    }
    // for FireFox and maybe Edge.
    toArray(obj) {
        let arr = [];
        for (let i = 0; i < obj.length; i++) {
            arr.push(obj[i]);
        }
        return arr;
    }
    prepareXml() {
        let xdoc = Parser.Parse(this.xml.trim());
        return xdoc;
    }
    renderAttribute(attribute) {
        return (h("span", null, "\u00A0", h("span", { class: "attr" }, attribute.name, "=\"", h("span", { class: "attr-value" }, attribute.value), "\"")));
    }
    renderNodeValue(nodeValue) {
        if (!nodeValue) {
            return null;
        }
        if (nodeValue.length > 150) {
            return (h("ul", null, h("li", null, nodeValue)));
        }
        return (h("span", null, nodeValue));
    }
    // rendering node. This function calls to itself in recursion way in case of child nodes
    renderNode(node) {
        if (!node) {
            return null;
        }
        // Note: FireFox thinks node.children is an array but it's not. FF transpiles next two lines of code (not comments)
        // into node.children.slice() but as I said before, node.children is not an array.
        // It's ... So I have to convert it into an array manually (yeah I know it's a stupid workaround)
        // TODO: I have to figure oute how to solve this problem properly
        let children = this.toArray(node.children); //[...node.children];
        let attributes = this.toArray(node.attributes); //[...node.attributes];
        let nodeValue = node.firstChild ? node.firstChild.nodeValue : null;
        nodeValue = nodeValue ? nodeValue.trim() : null;
        return (h("ul", null, h("li", null, h("div", { class: "element" }, "<", node.nodeName, attributes.map(a => this.renderAttribute(a)), ">"), h("div", { class: "element-content" }, this.renderNodeValue(nodeValue)), children.map(c => this.renderNode(c)), h("div", { class: "element" }, "</", node.nodeName, ">"))));
    }
    render() {
        if (this.xml === null || this.xml === undefined) {
            return null;
        }
        if (this.xml.length === 0) {
            return null;
        }
        let xdoc = null;
        try {
            xdoc = this.prepareXml();
        }
        catch (e) {
            console.error(e);
        }
        if (!xdoc || !xdoc.documentElement.childNodes) {
            return (h("code", null, this.xml));
        }
        return (h("p", null, h("code", null, this.renderNode(xdoc.documentElement))));
    }
    static get style() { return "code{\n    margin:.1rem .25rem 1rem .25rem;\n    padding:0;\n    color:#767676;\n    font-family: monospace, monospace;\n\n    text-shadow: 0 1px #fff;\n    direction: ltr;\n    text-align: left;\n    word-spacing: normal;\n    word-break: normal;\n    word-wrap: normal;\n    line-height: 1.2;\n    -moz-tab-size: 2; -o-tab-size: 2; tab-size: 2;\n    -webkit-hyphens: none; -moz-hyphens: none; -ms-hyphens: none; hyphens: none;\n}\n\ncode ul{\n    list-style-type: none;\n    margin:0;\n    padding-left:1rem;\n}\n\ncode div.element{\n    font-weight: bold;\n    color:darkred;\n    display:inline-block;\n}\n\ncode div.element-content {\n    font-weight: normal;\n    display:inline-block;\n}\n\ncode span.attr{\n    font-weight: bold;\n    color: #535353;\n}\n\ncode span.attr-value{\n    font-weight: normal;\n}\n\ncode div.comment{\n    color: darkgreen;\n}"; }
};

export { XmlViewerComponent as xml_viewer_component };
